Experimental Modules
====================

.. CAUTION::

    Here are some experimental modules. They have not yet undergone
    either sufficient testing, review, or refinement to be included within
    pymedphys proper. Consider everything under this module to be always at
    an "alpha" level of development. Consider that from any version to any
    version of pymedphys release these modules may change in such a way that
    breaks code that depends on it. Changes within the experimental module are
    not tracked within the `release notes </api/release-notes.html>`_.

.. toctree::
    :maxdepth: 1

    pinnacle
    pseudonymisation
